#
# See the file "LICENSE" for the full license governing this code.
#
require 'easy_type'
module Puppet
  Type.newtype(:wls_rcu) do
    def self.module_name;'wls_config' end
    desc <<-EOD
    This is the Oracle WebLogic RCU ( Repository creation utility) installer type

  EOD
    # TODO Add better and more documentation

    newproperty(:ensure) do
      include EasyType
      desc <<-EOD
    Whether a Repository should be created.

  EOD


      newvalue(:present, :event => :rcu_installed) do
        provider.present
      end

      newvalue(:absent, :event => :rcu_absent) do
        provider.absent
      end

      aliasvalue(:create, :present)
      aliasvalue(:delete, :absent)
      data_type("Optional[Enum['present','absent','create','delete']]")

      def retrieve
        provider.status
      end

      def sync
        event = super()
        # rubocop:disable all
        if property = @resource.property(:enable)
          val = property.retrieve
          property.sync unless property.safe_insync?(val)
        end
        # rubocop:enable all
        event
      end

    end

    newparam(:name) do
      include EasyType
      desc <<-EOT
        The prefix of the RCU.
      EOT
      data_type("Optional[String[1]]")
      isnamevar
    end

    newparam(:os_user) do
      include EasyType
      desc <<-EOT
        The weblogic operating system user.
      EOT
      data_type("Optional[String[1]]")
    end

    newparam(:sys_user) do
      include EasyType
      desc <<-EOT
        The sys user for the RCU check/install.
      EOT
    data_type("Optional[String[1]]")
    end

    newparam(:sys_password) do
      include EasyType
      desc <<-EOT
        The sys password for the RCU check/install.
      EOT
      data_type("Optional[String[1]]")
    end

    newparam(:jdbc_url) do
      include EasyType
      desc <<-EOT
        The jdbc url for the RCU check.
      EOT
      data_type("Optional[String[1]]")
    end

    newparam(:oracle_home) do
      include EasyType
      desc <<-EOT
        The oracle_home for the WLST location.
      EOT
      data_type("Optional[String[1]]")
    end

    newparam(:check_script) do
      include EasyType
      desc <<-EOT
        The check_script py script for the RCU Repository.
      EOT
      data_type("Optional[String[1]]")
    end

    newparam(:statement) do
      include EasyType
      desc <<-EOT
        The RCU statement.
      EOT
      data_type("Optional[String[1]]")
    end

    newparam(:jdk_home_dir) do
      include EasyType
      desc <<-EOT
        The jdk_home_dir.
      EOT
      data_type("Optional[String[1]]")
    end

  end
end
